## SQLite Lab

### Lab:

In this lab we extract the grocerydb database which is hosted on a github repository. We transform and load it into SQLite and then execute two sample queries: 
* Sum of the count_product column.
* Average of the count_product column.

Artitechtural diagram showing how the project works:

![etl](https://github.com/nogibjj/sqlite-lab-fj49/assets/101464414/2809102f-e363-4d23-8311-b7ec04f43804)

I took help from Claude.AI from the company Anthropic (Open AI's competitor)


